==> haskell-hls-pragmas-plugin-2.1.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.1.0.0-I5Yac7BrEeeA1TJLAkEsKN
key:                  hls-pragmas-plugin-2.1.0.0-I5Yac7BrEeeA1TJLAkEsKN
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  21527b5aa9b2cbfd6eb3d736cb6b2b38
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.1.0.0-I5Yac7BrEeeA1TJLAkEsKN
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-5K8PvZO4Jh1LEHVlaJYF8M
    fuzzy-0.1.1.0-H3TiB4mjNup7DBkdRLNC8p ghc-9.4.8
    ghcide-2.1.0.0-1VyHjvm41GN9dpQq6g7dnc
    hls-plugin-api-2.1.0.0-KgqOGj7ddh79pdBAmzh4H2
    lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-pragmas-plugin-2.1.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-pragmas-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-pragmas-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-pragmas-plugin-2.1.0.0-1jm1mdRpxZ28zXX1c8j7Rk
key:                  hls-pragmas-plugin-2.1.0.0-1jm1mdRpxZ28zXX1c8j7Rk
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Pragmas plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3cf7446cdc2ed6368942b0b3c54c25c7
exposed:              True
exposed-modules:      Ide.Plugin.Pragmas
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-pragmas-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-pragmas-plugin
hs-libraries:         HShls-pragmas-plugin-2.1.0.0-1jm1mdRpxZ28zXX1c8j7Rk
depends:
    base-4.17.2.1 containers-0.6.7 extra-1.7.16-5K8PvZO4Jh1LEHVlaJYF8M
    fuzzy-0.1.1.0-H3TiB4mjNup7DBkdRLNC8p ghc-9.4.8
    ghcide-2.1.0.0-13MzKdzkMl5nB5TLoyXA8
    hls-plugin-api-2.1.0.0-KgqOGj7ddh79pdBAmzh4H2
    lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR

haddock-interfaces:
    /usr/share/doc/haskell-hls-pragmas-plugin/html/hls-pragmas-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-pragmas-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
